==> locfit_1.00.tar.gz: locfit/src/local.h <==
/*
   Which version of locfit is being built?
   One of the following should be uncommented.
   If you change this after building one version
   of Locfit, then you'll also need to
   touch *.c
   at the unix prompt.
   For R compilation, both RVERSION and SVERSION should be uncommented.
   INTERFACE (not CVERSION) should be used, for user-written interfaces.
*/

/* #define CVERSION */
/* #define RVERSION */
#define SVERSION
/* #define INTERFACE */


/*
   Some older math libraries have no lgamma() function, and gamma(arg)
   actually returns log(gamma(arg)). If so, you need to change
   LGAMMA macro below.

   If all else fails, you can also use lflgamma().

   uncomment the definitions for erf, erfc and daws only if your
   math libraries don't include these functions.
*/
#define LGAMMA(arg) lgamma(arg)
/* #define erf(x) lferf(x)   */
/* #define erfc(x) lferfc(x) */
#define daws(x) lfdaws(x)

/*
   Does your system support popen() and pclose()
   for pipes? For most flavours of unix, yes.
   For other OS's, usually not, and you'll need to
   uncomment the following line.

   (This is only relevant if making the C version).
*/
/* #define NOPIPES */


/*
   the INT type is used for all integers provided in .C() calls
   from S.
   For the S version on 64 bit systems, this should be long int.
   For the R version, should be int.
   For the C version, either is adequate.
*/

typedef long int INT;

/*
  DIRSEP: '/' for unix; '\\' for DOS
*/
#define DIRSEP '/'

/******** NOTHING BELOW HERE NEEDS CHANGING **********/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>

#include "lfcons.h"
#include "lfstruc.h"
#include "lffuns.h"

#ifdef CVERSION
#undef printf
#define printf lfprintf
extern int lfprintf(const char *format, ...);
extern int printe(const char *format, ...);
#endif

#ifdef SVERSION
#define printe printf
#endif

#ifdef INTERFACE
#define printe printf
#endif

#define ERROR(args) printe("Error: "), printe args , printe("\n"), lf_error=1
#define WARN(args)  printe("Warning: "),printe args, printe("\n")

#define MAX(a,b) (((a)>(b)) ? (a) : (b))
#define MIN(a,b) (((a)<(b)) ? (a) : (b))
#define SGN(x) (((x)>0) ? 1 : -1)
#define SQR(x) ((x)*(x))
#define FSWAP(a,b) { double zz; zz = a; a = b; b = zz; }
#define ISWAP(a,b) { INT zz; zz = a; a = b; b = zz; }
#define NOSLN 0.1278433
#define GFACT 2.5
#define EFACT 3.0

#define MAXCOLOR 20
#define MAXWIN 5

extern INT lf_error;

==> locfit_1.0-1.tar.gz: locfit/src/local.h <==
/*
 *   Copyright (c) 1998-2000 Lucent Technologies.
 *   See README file for details.
 * 
 *
 *  Most of the changes formerly needed here are handled through
 *  the Makefiles and #ifdef's.
 *
 *
 */

#define RVERSION

/*
 *   DIRSEP: '/' for unix; '\\' for DOS
 */
#ifdef DOS
#define DIRSEP '\\'
#else
#define DIRSEP '/'
#endif


/*
   Some older math libraries have no lgamma() function, and gamma(arg)
   actually returns log(gamma(arg)). If so, you need to change
   LGAMMA macro below.

   If all else fails, you can also use lflgamma().

   Use the definitions for erf, erfc and daws only if your
   math libraries don't include these functions.
 */
#ifdef DOS
#define LGAMMA(arg) lflgamma(arg)
#define erf(x) lferf(x)
#define erfc(x) lferfc(x)
#else
#define LGAMMA(arg) lgamma(arg)
#endif
#define daws(x) lfdaws(x)


/*
   Does your system support popen() and pclose()
   for pipes? For most flavours of unix, yes.
   For other OS's, usually not, and you'll need to
   uncomment the following line.

   (This is only relevant if making the C version).
*/
/* #define NOPIPES */


/*
   (the #ifdef's below should now take care of this).
   the INT type is used for all integers provided in .C() calls from S.
   For the S version, this should be long int.
   For the R version, should be int.
   For the C version, either is adequate.
   Usually this only makes a difference on 64 bit systems.
*/

#ifdef RVERSION
typedef int INT;
#else
#ifdef SVERSION
typedef long int INT;
#else
typedef int INT;
#endif
#endif

/******** NOTHING BELOW HERE NEEDS CHANGING **********/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>

#ifdef RVERSION
# undef LGAMMA
# define LGAMMA(arg) Rf_lgammafn(arg)
extern double LGAMMA(double);
# define SVERSION
#endif

#include "lfcons.h"
#include "lfstruc.h"
#include "lffuns.h"

#ifdef CVERSION
#undef printf
#define printf lfprintf
extern int lfprintf(const char *format, ...);
extern int printe(const char *format, ...);
#endif

#ifdef SVERSION
#define printe printf
#endif

#ifdef INTERFACE
#define printe printf
#endif

#define ERROR(args) printe("Error: "), printe args , printe("\n"), lf_error=1
#define WARN(args)  printe("Warning: "),printe args, printe("\n")

#define MAX(a,b) (((a)>(b)) ? (a) : (b))
#define MIN(a,b) (((a)<(b)) ? (a) : (b))
#define SGN(x) (((x)>0) ? 1 : -1)
#define SQR(x) ((x)*(x))
#define FSWAP(a,b) { double zz; zz = a; a = b; b = zz; }
#define ISWAP(a,b) { INT zz; zz = a; a = b; b = zz; }
#define NOSLN 0.1278433
#define GFACT 2.5
#define EFACT 3.0

#define MAXCOLOR 20
#define MAXWIN 5

extern INT lf_error;
